@@ -341,7 +341,7 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
                 dict_saved_in_db = nested_dict()
             else:
                 dict_saved_in_db = nested_dict(dict_pushed)
-            if qntd_infos_path > 1:
+            if qntd_infos_path > 0:
                 for path_in_list in path_dir:
                     if contador_exect == 1:
                         current = dict_saved_in_db[path_in_list]
@@ -356,13 +356,15 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
             salva_infodb(dict_saved_in_db, antiblock=True)
             if antiblock == False:
                 editando = False
-        elif just_append == True and type(valor_atualizar) == dict:
-            for k, v in valor_atualizar.items():
-                temp_list = path_dir
-                temp_list.append(k)
-                atualiza_infodb(v, antiblock=True, path_dir_=temp_list)
+        elif just_append == True:
+            if type(valor_atualizar) == dict:
+                for k, v in valor_atualizar.items():
+                    temp_list = path_dir
+                    temp_list.append(k)
+                    update_infodb(v, antiblock=True, path_dir_=temp_list, just_append=False)
+            else:
+                update_infodb(valor_atualizar, antiblock=True, just_append=False)
             editando = False
-            
 
 def generate_key():
     return Fernet.generate_key()
